import { ContentConfig } from "/@/components/PageContent";
import { httpList } from "/@/api/purchase/orderRecordQuery";

import { h } from "vue";
import dayjs from "dayjs";
import { ElTag } from "element-plus";
import { statusOptions } from "/@/utils/details/reconciliation";
import { PAY_STATUS } from "/@/utils/details/purchase";
import { TAG_TYPE } from "/@/utils/global";
import { accAdd } from "/@/utils/calculation";

const columns = [
  {
    type: "selection",
    minWidth: 55,
    align: "left",
    hide: ({ checkList }) => !checkList.includes("勾选列")
  },
  {
    label: "序号",
    type: "index",
    minWidth: 60,
    align: "left",
    hide: ({ checkList }) => !checkList.includes("序号列")
  },
  {
    label: "对账编号",
    prop: "payNo",
    minWidth: 180,
    align: "left"
  },
  {
    label: "供应商编号",
    prop: "supplierNo",
    minWidth: 180,
    align: "left"
  },
  {
    label: "供应商名称",
    prop: "supplierName",
    minWidth: 180,
    align: "left"
  },
  {
    label: "标签类型",
    prop: "tag_id",
    width: "120px",
    cellRenderer: ({ row, props }) =>
      h(
        ElTag,
        {
          size: props.size
        },
        {
          default: () =>
            TAG_TYPE.find(t => t.value === row.tag_id)?.label || "无标签"
        }
      )
  },
  {
    label: "标签金额",
    prop: "tag_fee"
  },
  {
    label: "总额款",
    prop: "total_fee",
    minWidth: 180,
    align: "total_fee"
  },
  {
    label: "未付款金额",
    prop: "wpay_fee",
    minWidth: 180,
    align: "left",
    formatter: ({ tag_id, wpay_fee, tag_fee }) =>
      tag_id === "1" ? Number(wpay_fee) - Number(tag_fee) : wpay_fee
  },
  {
    label: "付款中金额",
    prop: "pay_fee",
    minWidth: 180,
    align: "left"
  },
  {
    label: "已付款金额",
    prop: "apay_fee",
    minWidth: 180,
    align: "left",
    formatter: ({ tag_id, apay_fee, tag_fee }) =>
      tag_id === "1" ? accAdd(apay_fee, tag_fee) : apay_fee
  },
  {
    label: "未回票金额",
    prop: "winv_fee",
    minWidth: 180,
    align: "left",
    formatter: ({ tag_id, winv_fee, tag_fee }) =>
      tag_id === "2" ? Number(winv_fee) - Number(tag_fee) : winv_fee
  },
  {
    label: "回票中",
    prop: "inv_fee",
    minWidth: 180
  },
  {
    label: "已回票金额",
    prop: "ainv_fee",
    minWidth: 180,
    align: "left",
    formatter: ({ tag_id, ainv_fee, tag_fee }) =>
      tag_id === "2" ? accAdd(ainv_fee, tag_fee) : ainv_fee
  },
  {
    label: "申请人",
    prop: "apply_name",
    minWidth: 180,
    align: "left"
  },
  {
    label: "付款状态",
    prop: "pay_status",
    width: "120px",
    cellRenderer: ({ row, props }) =>
      h(
        ElTag,
        {
          size: props.size
        },
        {
          default: () => PAY_STATUS.find(s => row.pay_status === s.value)?.label
        }
      )
  },
  {
    label: "状态",
    prop: "status",
    minWidth: 120,
    cellRenderer: ({ row, props }) =>
      h(
        ElTag,
        {
          size: props.size
        },
        {
          default: () => statusOptions.find(s => row.status === s.value)?.label
        }
      )
  },
  {
    label: "申请时间",
    minWidth: 180,
    prop: "addtime",
    formatter: ({ addtime }) => dayjs(addtime).format("YYYY-MM-DD HH:mm:ss")
  },
  {
    label: "操作",
    fixed: "right",
    width: 120,
    slot: "operation"
  }
];

const contentConfig: ContentConfig = {
  title: "订单对账",
  columns,
  deleteProp: "payNo",
  apis: {
    httpList
  },
  payProps: {
    prop: "payNo",
    type: "1"
  },
  returnProps: {
    prop: "payNo",
    type: "2"
  },
  powers: ["001", "002", "003", "004", "005", "006", "007", "008"]
};

export default contentConfig;
